#
# spec file for package jacktrip
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jacktrip
Version:        1.10.0
Release:        bp156.1.7
Summary:        Multi-machine network music performance over the Internet
License:        MIT
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://github.com/jcacerec/jacktrip
Source0:        https://github.com/jcacerec/jacktrip/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        Simple-FFT.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libqt5-linguist
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-Jinja2
BuildRequires:  python3-PyYAML
BuildRequires:  rtaudio-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5NetworkAuth)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)

%description
JackTrip is a system used for multi-machine network performance over the
Internet. It supports any number of channels (as many as the
computer/network can handle) of bidirectional, high quality, uncompressed
audio signal streaming.

%prep
%autosetup
pushd externals
tar xf %{_sourcedir}/Simple-FFT.tar.gz
popd

%build
mv build .build
%meson
%meson_build

%install
%meson_install

%files
%doc README.md
%license LICENSE.md
%{_bindir}/jacktrip
%{_datadir}/applications/*
%{_datadir}/metainfo/*
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%dir %{_datadir}/icons/hicolor/symbolic
%dir %{_datadir}/icons/hicolor/symbolic/apps
%{_datadir}/icons/hicolor/*/apps/*

%changelog
* Tue Jun 20 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.10.0
  * Use Device Authorization Flow by @dhing1024 in #1037
  * Improvements and Fixes for Device Flow Code by @dhing1024 in #1039
  * More Informative Loading Message by @dhing1024 in #1041
  * Cleanup Audio When Switching to Classic Mode by @dhing1024 in #1042
  * Optimize PLC regulator performance by using double instead of long double by @mikedickey in #1043
  * Optimized performance of virtual studio volume meters by @mikedickey in #1044
  * Detect Feedback Loops by @dhing1024 in #1035
  * Optionally Disable Feedback Detection by @dhing1024 in #1049
  * Fixing connected view errors by @nwang92 in #1057
  * Improve FFT Performance by @dhing1024 in #1055
  * Fixed issue with RTAudio scanning interfaces several times at startup by @mikedickey in #1063
  * Add audio interface blacklist to exclude Realtek ASIO driver by @mikedickey in #1066
  * Add timestamps to debug window by @psiborg112 in #1068
  * Updating new FeedbackDetection setting to be enabled by default by @mikedickey in #1073
  * Fixing bug with "Change Device Settings" dialog being empty by @mikedickey in #1072
- Provide separate source for Simple-FFT library (https://github.com/jacktrip/jacktrip/issues/1079)
* Mon May 15 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.9.0
  * Fix openssl v3 compatibility failures with Linux static build by @mikedickey in #1005
  * Show error message when single studio limit is reached by @nwang92 in #1008
  * Fixing Play Test Tone button on Linux by @mikedickey in #1010
  * Remove yes/no at first open by @mattahorton in #1009
  * Moving faust-generated code out of header files by @mikedickey in #1011
  * Enable Local Monitoring of Inputs by @dhing1024 in #1014
  * Output Volume Meters Include Monitor by @dhing1024 in #1017
  * Changing "All Devices" for non-ASIO category to be "High Latency" by @mikedickey in #1020
  * GHA: add an option to wait for static Qt build by @dyfer in #1023
  * Feature/adding icons to connected view by @nwang92 in #1022
  * Updating some tooltips, sliders and positioning for connected interface by @mikedickey in #1024
  * Hide classic mode link after first launch by @mattahorton in #1025
  * Monitor Controls from API by @dhing1024 in #1026
  * Refresh devices when opening the popup by @nwang92 in #1012
* Thu Apr  6 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.8.1
  * Add tooltips to audio settings to explain "input device" and "output device"
  * Allow IP check to work with IPv6 only
  * make buffer size and sample rate settable for Pipewire
  * Fixes for Special Characters in Device Names
  * Adding a simple link to create your first studio to VS login page
  * Fixing QML error on undefined boolean
  * AudioSettings should show the currently selected device
  * Save Output Channels Settings
* Tue Mar 21 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.8.0
  * Replace icons from unknown sources
  * Replace share/invite icon
  * Parse command line for GUI
  * Select and Configure Input Channels
  * Replace QVector in meter code
  * Move inputMixMode into AudioInterface.h
  * Fix Output Device Selection Bug
  * Bugfix Refresh Button & Device Combo State
  * Fix crash when using JACK
  * Change text on button when deeplinked
  * Select Output Channels
  * Minor Fix for Refresh Button on Settings Page
  * Improve Sign In For First Time Users
  * Only check IP address if loading standard GUI
* Mon Feb 20 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.7.1
  * Correcting the year
  * Add QuickControls2 dependency to Meson and Qmake, and enable ahead-of-time compilation of QMLs
  * Make Video Button Available to Non-Admins
  * Use random bind port to avoid client collision
  * Attempt to fix a couple of memory leaks
  * Reorganize Audio Setup and Settings Screens
  * Bugfix/plcBigFPP
  * Bugfix Manage Button Crashes App in Browse View
  * Remove beta1 name
  * Add refresh button back to settings
* Fri Jan 27 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.7.0
  - (added) VS Mode - Start and join inactive studios
  - (added) JackTrip now prints build info on running from console
  - (added) VS Mode - supports changing output volume from the server
  - (added) VS Mode - Link to video on VS web when connected
  - (updated) signing now happens in the main build workflow
  - (updated) VS mode sorts active studios above inactive studios
  - (updated) replaced many ifdefs with if constexpr
  - (updated) After signing out of VS mode, you will be asked to sign back in on the web
  - (fixed) network stats failing after studio start
  - (fixed) occasional immediate disconnects
  - (fixed) segfault issue due to ifdefs
  - (fixed) turned a comment warning into an appropriate error
  - (fixed) VS Mode - Join issue withs studios started in app
  - (fixed) hanging app after refreshing studios
  - (fixed) VS Mode - TCP 19 error after starting a studio
* Mon Jan  9 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.6.8
  * Fix Window Resize Rendering
  * Fix yes button on start screen
  * VU meters in standard mode
  * Studios Page FTUX
  * Adding ability to play test tone
  * Set bit resolution for hub server
  * Show input vu meter in settings
  * delay heartbeat until after device is registered
  * Fix device disconnect crashes
  * Fix cache
  * more on https://github.com/jacktrip/jacktrip/releases/
* Wed Nov  3 2021 Fabio Pesari <fpesari@tuxfamily.org>
- Updated to version 1.4.0
  * (added) optional GUI from QJackTrip
  * (added) authentication in hub server mode
  * (added) different number of sending and receiving channels
  * (added) append thread IDs to jack client names
  * (added) new patcher mechanism that doesn't delete existing
    connections
  * (added) MkDocs based documentation
  * (added) weak jack linking
  * (added) manpage
  * (added) MSVC build
  * (added) RtAudio Meson subproject
  * (added) formatting with clang-format
  * (added) static analysis with clang-tidy
  * (added) cross compilation for Windows
  * (added) flatpaks
  * (added) appstream
  * (added) automated builds and deployment for Linux, macOS and
    Windows
  * (added) macOS and Windows Installers
  * (fixed) regression in remote client name handling
  * (fixed) long jack client names   * (> 27 characters) in 1.9.11
  * (fixed) Hardcode Derived Class Names of ProcessPlugins to
    prevent undefined behavior
  * (update) QJackTrip and JackTrip are now identical
  * (update) Change helpscreen wording for --broadcast argument
  * (update) jitter buffer alternatives
  * (update) RtAudio revive
  * (update) RtAudio device selection
  * (update) build script moved to root directory
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.0
  * (added) async networking in hub listener
  * (added) limiter, compressor, reverb
  * (added) examine audio delay
  * (added) jitter buffer alternatives
  * (added) broadcast output ports
  * (added) PREFIX variable for installation path
  * (added) disconnect on timeout
  * (added) SIGTERM
  * (added) simulate packet loss, jitter
  * (added) hubpatch 5, no auto patching
  * (added) jack client name length check
  * (added) scripts/hubMode/test_hub_mode_server_and_client.sh
  * (fixed) misc. typos, indentation
  * (fixed) short form IO stat options
  * (fixed) nullptr jack server name when creating jack client
  * (fixed) stop ring buffer blocking when jack has been stopped
  * (fixed) JMess handling of non-western characters
  * (fixed) closing curly brace on mJackTrip client creation
  * (fixed) Warnings
  * (fixed) remove rtaudio device and mpeeraddress msgs.
  * (fixed) signal and slot connections
  * (fixed) incorrect dependency from jacktrip_main
  * (update) RT thread priority for network I/O
  * (update) clipping to saturation
  * (update) build instructions
  version 1.2.2:
  * (added) bindPort range to reject oddball connections
  * (fixed) jack client name strings
- Switch build to meson
* Fri Aug 21 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.1
  - (added) src/build script builds in ../builddir
  - (fixed) refactor "Master" to be "Hub"
  - (fixed) 1.2.1 correctly versioned and tagged
  1.2 (release candidate, not yet tagged)
  - (added) jack patching modes (-p) for Hub Mode server (-S)
  - (fixed) Compilation under ubuntu
  - (removed) setRealtimeProcessPriority()
  - (removed) Rtaudio mode (but still has dependencies)
  - (fixed) IPv4-mapped IPv6 addressing bug
  ...
  - (fixed) Fixed compilation for  MacOSX10.11.sdk.
  - (update) Updated to RtAudio 4.1.1, and using shared lib in linux.
* Fri Mar  9 2018 aloisio@gmx.com
- Update to version 1.1
  * (added) Support for RtAudio. Jacktrip can now be used without
    Jack
  * (added) DNS Look-up support, now one machine can have a private
    IP (but still needs to have UDP ports open)
  * (added) New port to Windows XP and Windows Vista (experimental
    and not tested for a long time, only when using jacktrip as a
    library)
  * (added) Multiclient Server (experimental and not exposed in the
    executable)
- Dropped jacktrip-1.0.5-gcc47.patch (merged upstream)
- New homepage
- Spec cleanup
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build with gcc 4.7
* Sat Apr 21 2012 pascal.bleser@opensuse.org
- initial version (1.0.5+2)
